// testPhidgetIK.pde - test the phidget IK portion of phidget library

phidgetAdvancedServo servo;
PFont myFont;

void setup()
{
  // set screen size
  size( 320, 240 );
  
  // get phidget IK started and wait up to 1s for attach
  servo = new phidgetAdvancedServo();
//  servo.waitForAttachment( 1000 );
  
  // set up font
  myFont = createFont("arial", 10);
  textFont(myFont);

}


// use mouse pressed to engage/disengage motors
void mousePressed() {
  for( int i = 0; i < servo.getMotorCount(); i++ ) {
    // engage/disengage motor
    int xmotor = 20;
    int ymotor = i * 20 + 50;
    if ( dist( xmotor, ymotor, mouseX, mouseY ) < 5 ) {
      // mouse click over control - toggle engaged
      servo.setEngaged( i, ! servo.getEngaged( i ) );
    }
    
    // set motor position
    if ( 40 <= mouseX && mouseX <= 300 && abs(mouseY - ymotor) < 5 ) {
      // mouse clicked over slider
      float position = map( mouseX, 40.0, 300.0, -1.0, 1.0 );
      servo.setPosition( i, position );
    }
  }
}


void draw()
{
  background( 200 );
  
  // show attach status
  if ( servo.isAttached() ) fill( 0, 255, 0 );
  else fill( 255, 0, 0 );
  noStroke();
  ellipse( 20, 20, 10, 10 );

  // show serial number and version
  fill(0);
  text( servo.serial(), 40, 25 );
  text( servo.version(), 40, 35 );

  // display motor engage and position slider
  for( int i = 0; i < servo.getMotorCount(); i++ ) {
    if ( servo.getEngaged( i ) ) {
      noStroke();
      fill( 0, 255, 0 );
    } else {
      stroke(0);
      noFill();
    }
    ellipse( 20, i * 20 + 50, 10, 10 );
    
    if ( servo.getEngaged( i ) ) {
      stroke(0);
      line( 40, i*20 + 50, 300, i*20 +50 );
      noStroke();
      fill( 0, 0, 255 );
      float posn = servo.getPosition(i);
      ellipse( map( posn, -1.0, 1.0, 40.0, 300.0 ), i*20+50, 10, 10 );
    }
  }

  
  
  if (keyPressed) {
    servo.close();
    exit();
  }
}

